<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Selaimen ulkopuolellakin on elämää!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versio: %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Lisensoitu henkilölle: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 on ilmainen ohjelma, mutta sen kehittäminen vie kallista aikaa.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Voit tukea %2-kehitystä jatkumista tekemällä &lt;a href=&apos;%1&apos;&gt;lahjoituksen&lt;/a&gt;.</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Käännä %1 äidinkielellesi käyttämällä %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation>%1 voimistama</translation>
    </message>
    <message>
        <source>Open-source software</source>
        <translation>Avoimen lähdekoodin ohjelmisto</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Kuvakkeen suunnitteli %1.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Julkaistu &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; -lisenssillä</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Syötä tähän lisenssitietosi</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Sähköposti:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Koodi:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Lisensioi %1.</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>Täysversio mahdollistaa videoiden katselun ilman keskeytyksiä.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ostamalla täyden version tuet kovaa työtäni sovelluksen %1 parissa.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Käytä demoa</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Syötä lisenssi</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Osta lisenssi</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Lataa</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Tekijältä %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation><numerusform>Sinulle on %n uusi video</numerusform><numerusform>Sinulle on %n uutta videota</numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Kaikki videot</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Katsomattomat videot</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Viimeksi päivitetyt</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Viimeksi lisätyt</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Viimeksi katsotut</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Katsotuimmat</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Järjestysperuste</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Merkitse kaikki katsotuiksi</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Näytä päivitetyt</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>Sinulla ei ole tilauksia. Käytä tähtisymbolia tilataksesi kanavia.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Kaikki videot</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Katsomattomat videot</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Merkitse katsotuksi</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Lopeta tilaus</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>Päivitettyjä tilauksia ei ole tällä hetkellä.</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Juuri nyt</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation><numerusform>%n tunti sitten</numerusform><numerusform>%n tuntia sitten</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation><numerusform>%n päivä sitten</numerusform><numerusform>%n päivää sitten</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation><numerusform>%n kuukausi sitten</numerusform><numerusform>%n kuukautta sitten</numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation>K</translation>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation>M</translation>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>%1 views</source>
        <translation>Katsottu %1 kertaa</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation><numerusform>%n viikko sitten</numerusform><numerusform>%n viikkoa sitten</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s) ago</source>
        <translation><numerusform>%n vuotta sitten</numerusform><numerusform>%n vuotta sitten</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>tavua</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>Kt</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>Mt</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>tavua/sekunnissa</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>Kt/s</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>Mt/s</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunttia</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuuttia</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 jäljellä</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>%1 ladattu ajassa %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Lataus valmistui</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation><numerusform>%n lataus</numerusform><numerusform>%n latausta</numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Vaihda sijaintia...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Valitse latausten sijainti</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Lataus sijaintia on muutettu.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Nykyiset lataukset menevät vanhaan sijaintiin.</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Ladataan kansioon: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>Suoritustiedostoa on muokattu, kyseessä saattaa olla virus.</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 ei käynnisty. Yritä uudelleenasennusta.</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Lopeta</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Asenna uudelleen</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Toista</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Keskeytä</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Toista/keskeytä</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Pysäytä toisto nykyisen kappaleen jälkeen</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Seuraava kappale</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Edellinen kappale</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Lisää äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Vähennä äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Vaimenna</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Kelaa eteenpäin</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Kelaa taaksepäin</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Etsi videoita ja kanavia avainsanalla</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Selaa</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Selaa videoita ryhmien mukaan</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Tilaukset</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Kanavatilaukset</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Tee olosi kotoisaksi</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ikkuna</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Pienennä</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Pysäytä</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Pysäytä toisto ja palaa hakuruutuun</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>E&amp;dellinen</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Siirry takaisin edelliseen kappaleeseen</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>&amp;Hyppää yli</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Siirry seuraavaan videoon</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Toista</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Jatka toistoa</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Koko näytön tila</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Siirry koko näytön tilaan</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Kompakti &amp;tila</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Piilota soittolista sekä työkalupalkki</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Avaa &amp;YouTube-sivu</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Keskeytä toisto ja mene videon YouTube-sivulle</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Kopioi YouTube-&amp;linkki</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Kopioi nykyisen videon YouTube-linkki leikepöydälle</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Kopioi videovirran &amp;verkko-osoite</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Kopioi nykyisen videovirran osoite leikepöydälle</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Etsi videon &amp;osat</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Löydä videon muut osat toivottavasti oikeassa järjestyksessä</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Poista valitut videot toistolistalta</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Siirrä &amp;ylös</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Siirrä valitut videot ylemmäksi soittolistalla</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Sirrä &amp;alas</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Siirrä valitut videot alemmaksi soittolistalla</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Ty&amp;hjennä viimeisimmät haut</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Tyhjennä hakuhistoria. Tätä toimintoa ei voi kumota.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Näkemiin</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Nettisivusto</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 netissä</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Tee &amp;lahjoitus</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Tue %1n jatkokehitystä</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Tietoja</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Tietoja %1sta</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Vaimenna ääni</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Aloita toisto &amp;manuaalisesti</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Aloittaa videoiden toiston manuaalisesti</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Lataukset</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Näytä tietoja latauksista</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Lataa</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Lataa nykyinen video</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Ota &amp;tilannevedos</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Tilaa kanava</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Jaa nykyinen video palvelulla %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>&amp;Sähköposti</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Sähköposti</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Pysy päällimmäisenä</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Py&amp;säytä toisto tämän videon jälkeen</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Ilmoita ongelmasta...</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Määritä haku uudelleen...</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Lisää...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>&amp;Aiheeseen liittyvät videot</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Katso nykyiseen videoon liittyvät videot</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Avaa &amp;selaimessa...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Rajoitettu tila</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Piilota videot, jotka saattavat sisältää soveltumatonta sisältöä</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation>Näytä/piilota &amp;valikkopalkki</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Valikko</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Pidätkö %1sta? Arvostele se!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Osta %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Sovellus</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Toisto</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>S&amp;oittolista</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Video</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Jaa</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Paina näppäinyhdistelmää %1 nostaaksesi tai %2 laskeaksesi äänenvoimakkuutta</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Valitse sisältösi sijainti</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Avataan kohdetta %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Haluatko, että %1 sulkeutuu vaikka lataus on kesken?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>Jos suljet %1n nyt niin tämä lataus keskeytetään.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Sulje ja peru lataus</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Odota latauksen valmistumista</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Virhe: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Keskeytä</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Keskeytä toisto</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Ladataan...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation> Poistu &amp;koko näytön tilasta</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Aikaa jäljellä: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Äänentaso: %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Ääni on vaimennettu</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Ääni ei ole vaimennettu</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Korkein videonlaatu on rajoitettu tarkkuuteen %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Yksityisyytesi on nyt turvattu</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Lataukset ovat valmistuneet</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation>Saat valikkopalkin näkyviin painamalla ALT-näppäintä</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Voit nyt liittää YouTube-linkin johonkin toiseen sovellukseen</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Voit nyt liittää videovirran osoitteen (URL) johonkin toiseen sovellukseen</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>Osoite on käytössä vain rajoitetun ajan.</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Ladataan %1ta/tä</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>/</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>osa</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>jakso</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Lähetetty palvelusta %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Peru kanavan %1 tilaus</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Tilaa kanava %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation>Vaihdettiin tähän %1</translation>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Kohteen %1 tilaus lopetettu</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Tilattu %1</translation>
    </message>
    <message>
        <source>Rewind %1 seconds</source>
        <translation>Kelaa taaksepäin %1 sekuntia</translation>
    </message>
    <message>
        <source>Fast forward %1 seconds</source>
        <translation>Pikakelaa eteenpäin %1 sekuntia</translation>
    </message>
    <message>
        <source>channel</source>
        <translation>kanava</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Uusi versio sovelluksesta %1 on saatavilla!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 on nyt saatavilla. Sinulla on %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Haluatko ladata sen nyt?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Ohita tämä versio</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Muistuta minua myöhemmin</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Asenna päivitys</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Liitä</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation>Valitse video</translation>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 / %2 (%3) — %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Valmistellaan</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Epäonnistui</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Pysäytetty</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Pysäytä lataus</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Avaa %1ssa/ssä</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Avaa yläkansio</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Käynnistä lataus uudelleen</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Näytä %1 lisää</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Ei videoita</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Ei enempää videoita</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Järjestysperuste</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Olennaisuus</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Päiväys</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Katselukerrat</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Arvostelu</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Milloin tahansa</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>7 päivää</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>30 päivää</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kesto</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Lyhyt</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Keskipituinen</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Pitkä</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Vähemmän kuin 4 minuuttia</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>4-20 minuutin välillä</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Pidempi kuin 20 minuuttia</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Laatu</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Tänä vuonna</translation>
    </message>
    <message>
        <source>HD</source>
        <translation>HD</translation>
    </message>
    <message>
        <source>4K</source>
        <translation>4K</translation>
    </message>
    <message>
        <source>HDR</source>
        <translation>HDR</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Tervetuloa &lt;a href=&apos;%1&apos;&gt;%2en&lt;/a&gt;</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>aloittaaksesi videoiden katselu.</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>hakusana</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Syötä</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Viimeisimmät hakusanat</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Viimeisimmät kanavat</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Hanki täysversio</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Need a remote control for %1? Try %2!</source>
        <translation>Tarvitsetko kaukosäätimen %1 :lle? Kokeile %2!</translation>
    </message>
    <message>
        <source>I keep improving %1 to make it the best I can. Support this work!</source>
        <translation>Jatkan %1 :n parantamista tehdäkseni siitä niin hyvän kuin kykenen. Tue tätä työtä!</translation>
    </message>
    <message>
        <source>An update is ready to be installed. Quit and install update.</source>
        <translation>Päivitys on valmiina asennettavaksi. Poistu sovelluksesta asentaaksesi päivityksen.</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Takaisin</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>&amp;Eteenpäin</translation>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Eteenpäin kohteeseen %1</translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Takaisin kohteeseen %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Määritä haku uudelleen</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Tarkoititko: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Vaihda sijaintia...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Tilannevedos tallennettu polkuun %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Tilannevedoksien sijainti muutettu.</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Suosituimmat</translation>
    </message>
    <message>
        <source>Trending</source>
        <translation>Trendaavat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musiikki</translation>
    </message>
    <message>
        <source>News</source>
        <translation>Uutiset</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Elokuvat</translation>
    </message>
    <message>
        <source>Gaming</source>
        <translation>Pelaaminen</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Ladataan päivitystä...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Ladataan %1...</translation>
    </message>
</context>
<context>
    <name>Updater</name>
    <message>
        <source>Check for Updates...</source>
        <translation>Tarkista onko päivityksiä saatavilla...</translation>
    </message>
    <message>
        <source>Version %1 is available...</source>
        <translation>Versio %1 on saatavilla...</translation>
    </message>
    <message>
        <source>Downloading version %1...</source>
        <translation>Ladataan versiota %1...</translation>
    </message>
    <message>
        <source>Restart to Update</source>
        <translation>Uudelleenkäynnistä päivittääksesi</translation>
    </message>
    <message>
        <source>Version %1 download failed</source>
        <translation>Version %1 lataaminen epäonnistui</translation>
    </message>
    <message>
        <source>Check for Updates</source>
        <translation>Tarkista onko päivityksiä saatavilla</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Lataa päivitys</translation>
    </message>
    <message>
        <source>Downloading update...</source>
        <translation>Ladataan päivitystä...</translation>
    </message>
    <message>
        <source>Retry Update Download</source>
        <translation>Yritä ladata päivitystä uudelleen</translation>
    </message>
    <message>
        <source>You have the latest version.</source>
        <translation>Käytössä on jo viimeisin versio.</translation>
    </message>
    <message>
        <source>Version %1 is available.</source>
        <translation>Versio %1 on saatavissa.</translation>
    </message>
    <message>
        <source>An update has been downloaded and is ready to be installed.</source>
        <translation>Päivitys ladattiin ja on nyt valmis asennettavaksi.</translation>
    </message>
</context>
<context>
    <name>YTJSVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Videostriimiä ei saada kohteelle %1</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentiina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Belgia</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasilia</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Kanada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Kolumbia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>Tšekin tasavalta</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egypti</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Ranska</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Saksa</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Kreikka</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hongkong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Unkari</translation>
    </message>
    <message>
        <source>India</source>
        <translation>Intia</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanti</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japani</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordania</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malesia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>Meksiko</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marokko</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Alankomaat</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Uusi-Seelanti</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Peru</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filippiinit</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Puola</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Venäjä</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Saudi-Arabia</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapore</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Etelä-Afrikka</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Etelä-Korea</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>Espanja</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Ruotsi</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Tunisia</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turkki</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>Uganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Yhdistyneet arabiemiirikunnat</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Yhdistynyt kuningaskunta</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Jemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Maailmanlaajuinen</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>Videostriimiä ei saada kohteelle %1</translation>
    </message>
</context>
<context>
    <name>updater::DefaultUpdater</name>
    <message>
        <source>There are currently no updates available.</source>
        <translation>Päivityksiä ei ole tällä hetkellä saatavilla.</translation>
    </message>
</context>
<context>
    <name>updater::Dialog</name>
    <message>
        <source>You already have the latest version</source>
        <translation>Käytössä on jo viimeisin versio</translation>
    </message>
    <message>
        <source>Downloading %1 %2...</source>
        <translation>Ladataan %1 %2...</translation>
    </message>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Uusi versio sovelluksesta %1 on saatavilla!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 on nyt saatavilla. Sinulla on %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Haluatko ladata sen nyt?</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Muistuta minua myöhemmin</translation>
    </message>
    <message>
        <source>Download Update</source>
        <translation>Lataa päivitys</translation>
    </message>
</context>
</TS>